from .base import Base
from datetime import datetime


class Projects(Base):
    """Class for Projects APIs."""

    def __init__(self):
        Base.__init__(self, attribute_type='PROJECT')


    def sync(self, sync_after: datetime = None):
        """
        Syncs the latest API data to DB.
        """
        generator = self.get_all_generator(sync_after)
        for items in generator:
            project_attributes = []
            for project in items['data']:
                if self.attribute_is_valid(project):
                    if project['sub_project']:
                        project['name'] = '{0} / {1}'.format(project['name'], project['sub_project'])

                    project_attributes.append({
                        'attribute_type': self.attribute_type,
                        'display_name': self.attribute_type.replace('_', ' ').title(),
                        'value': project['name'],
                        'active': project['is_enabled'],
                        'source_id': project['id']
                    })

            self.bulk_create_or_update_expense_attributes(project_attributes, True)



from .base import Base


class ExpenseFields(Base):
    """
    Class For Expense Fields
    """

    def __init__(self):
        Base.__init__(self, attribute_type='EXPENSE_FIELDS')

    def get_project_field_id(self):
        """
        Get Project Field ID
        """
        query_params = {'limit': 1, 'order': 'updated_at.desc', 'offset': 0, 'field_name': 'eq.Project', 'is_custom': 'eq.False'}
        projects = self.connection.list(query_params)

        project_field_id = None

        if (len(projects['data'])) > 0:
            project_field_id = projects['data'][0]['id']

        return project_field_id


    def bulk_post_dependent_expense_field_values(self, data):
        """
        Post of Expense Field Values
        """
        payload = {
            'data': data
        }
        return self.connection.bulk_post_dependent_expense_field_values(payload)


    def get_dependent_expense_field_values(self):
        """
        Get of Dependent Expense Field Values
        """

        return self.connection.get_dependent_expense_field_values()



from .expenses import Expenses
from .employees import  Employees
from .categories import Categories
from .projects import Projects
from .cost_centers import CostCenters
from .expense_custom_fields import ExpenseCustomFields
from .corporate_cards  import CorporateCards
from .reimbursements import Reimbursements
from .tax_groups import TaxGroups
from .merchants import Merchants
from .files import Files
from .departments import Departments
from .expense_fields import ExpenseFields

__all__ = [
    'Expenses',
    'Employees',
    'Categories',
    'Projects',
    'CostCenters',
    'ExpenseCustomFields',
    'CorporateCards',
    'Reimbursements',
    'TaxGroups',
    'Merchants',
    'Files',
    'Departments',
    'ExpenseFields'
]
